@@ -1,8 +1,8 @@
 ## RQuantLib -- R interface to the QuantLib libraries
 ##
-## Copyright 2002 Dirk Eddelbuettel <edd@debian.org>
+## Copyright 2002, 2005 Dirk Eddelbuettel <edd@debian.org>
 ##
-## $Id: option.R,v 1.2 2002/02/26 03:40:05 edd Exp edd $
+## $Id: option.R,v 1.5 2005/08/07 02:05:27 edd Exp $
 ##
 ## This file is part of the RQuantLib library for GNU R.
 ## It is made available under the terms of the GNU General Public
@@ -20,10 +20,9 @@
 ## Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 ## MA 02111-1307, USA
 
-EuropeanOption <- function(x, ...) {
-  if (is.null(class(x)))
-    class(x) <- data.class(x)
-  UseMethod("EuropeanOption", x, ...)
+EuropeanOption <- function(type, underlying, strike, dividendYield,
+                           riskFreeRate, maturity, volatility) {
+  UseMethod("EuropeanOption")
 }
 
 EuropeanOption.default <- function(type, underlying, strike, dividendYield,
@@ -35,15 +34,16 @@ EuropeanOption.default <- function(type, underlying, strike, dividendYield,
                     dividendYield=as.double(dividendYield),
                     riskFreeRate=as.double(riskFreeRate),
                     maturity=as.double(maturity),
-                    volatility=as.double(volatility)))
+                    volatility=as.double(volatility)),
+               PACKAGE="RQuantLib")
   class(val) <- c("EuropeanOption", "Option")
   val
 }
 
-AmericanOption <- function(x, ...) {
-  if (is.null(class(x)))
-    class(x) <- data.class(x)
-  UseMethod("AmericanOption", x, ...)
+AmericanOption <- function(type, underlying, strike, dividendYield,
+                           riskFreeRate, maturity, volatility,
+                           timeSteps=150, gridPoints=151) {
+  UseMethod("AmericanOption")
 }
 
 AmericanOption.default <- function(type, underlying, strike, dividendYield,
@@ -58,15 +58,16 @@ AmericanOption.default <- function(type, underlying, strike, dividendYield,
                     maturity=as.double(maturity),
                     volatility=as.double(volatility),
                     timeSteps=as.integer(timeSteps),
-                    gridPoints=as.integer(gridPoints)))
+                    gridPoints=as.integer(gridPoints)),
+               PACKAGE="RQuantLib")
   class(val) <- c("AmericanOption","Option")
   val
 }
 
-BinaryOption <- function(x, ...) {
-  if (is.null(class(x)))
-    class(x) <- data.class(x)
-  UseMethod("BinaryOption", x, ...)
+BinaryOption <- function(type, underlying, strike, dividendYield,
+                         riskFreeRate, maturity, volatility,
+                         cashPayoff) {
+  UseMethod("BinaryOption")
 }
 
 BinaryOption.default <- function(type, underlying, strike, dividendYield,
@@ -80,15 +81,16 @@ BinaryOption.default <- function(type, underlying, strike, dividendYield,
                     riskFreeRate=as.double(riskFreeRate),
                     maturity=as.double(maturity),
                     volatility=as.double(volatility),
-                    cashPayoff=as.double(cashPayoff)))
+                    cashPayoff=as.double(cashPayoff)),
+               PACKAGE="RQuantLib")
   class(val) <- c("BinaryOption", "Option")
   val
 }
 
-BarrierOption <- function(x, ...) {
-  if (is.null(class(x)))
-    class(x) <- data.class(x)
-  UseMethod("BarrierOption", x, ...)
+BarrierOption <- function(barrType, type, underlying, strike,
+                          dividendYield, riskFreeRate, maturity,
+                          volatility, barrier, rebate=0.0) {
+  UseMethod("BarrierOption")
 }
 
 BarrierOption.default <- function(barrType, type, underlying, strike,
@@ -104,26 +106,28 @@ BarrierOption.default <- function(barrType, type, underlying, strike,
                     maturity=as.double(maturity),
                     volatility=as.double(volatility),
                     barrier=as.double(barrier),
-                    rebate=as.double(rebate)))
+                    rebate=as.double(rebate)),
+               PACKAGE="RQuantLib")
   class(val) <- c("BarrierOption", "Option")
   val
 }
 
 plot.Option <- function(x, ...) {
-  warning(paste("No plotting available for class", class(x)[1],"\n"))
+  warning("No plotting available for class", class(x)[1],"\n")
   invisible(x)
 }
 
-print.Option <- function(x, digits=options('digits')[[1]], ...) {
-  cat(paste("Concise summary of valuation for", class(x)[1], "\n"))
-  print(unlist(x[1:7]), digits=digits)
+print.Option <- function(x, digits=4, ...) {
+  cat("Concise summary of valuation for", class(x)[1], "\n")
+  print(round(unlist(x[1:7]), digits))
   invisible(x)
 }
 
-summary.Option <- function(object, digits=options('digits')[[1]], ...) {
-  cat(paste("Detailed summary of valuation for", class(object)[1], "\n"))
-  print(unlist(object[1:7]),digits=digits)
-  print(unlist(object[["parameters"]]),digits=digits)
+summary.Option <- function(object, digits=4, ...) {
+  cat("Detailed summary of valuation for", class(object)[1], "\n")
+  print(round(unlist(object[1:7]), digits))
+  cat("with parameters\n")
+  print(unlist(object[["parameters"]]))
   invisible(object)
 }
 
